; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1




;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
;--------------------
;AI activation
;--------------------

[Command]
name = "ai"
command = U, D, B, F, U, a, F, b, U, F, y, z, F
time = 1
[Command]
name = "ai2"
command = F, b, U, F, y, z, F, U, D, B, F, U, a
time = 1
[Command]
name = "ai3"
command = a, F, b, U, D, B, F, U, B, F, y, z, F, x
time = 1
[Command]
name = "ai4"
command = c, a, F, z, U, F, y, z, F, x, D, B, F, U, B
time = 1
[Command]
name = "ai5"
command = z, c, U, F, c, U, F, D, F, x, z, c, z, c, z, c
time = 1
[Command]
name = "ai6"
command = z, c, U, F, c, U, F, U, F, y, z, F, x, D
time = 1
[Command]
name = "ai7"
command = z ,c ,z ,c ,z ,c ,z ,c ,z ,c ,z ,U ,F ,c ,U
time = 1
[Command]
name = "ai8"
command = z, c, U, F, U, F, y, z, F, x, D, a, F, z, U
time = 1
[Command]
name = "ai9"
command = z, c, z, F, B, U, D, F, DF, z, U, c, U, F, D
time = 1
[Command]
name = "ai10"
command = z, c, D, F, U, DF ,y , z+c, F, x, D, a, F, z, U
time = 1
[Command]
name = "ai11"
command = F, x, D, a, F, z, U, z, c, D, F, U, DF, y, z+c
time = 1
[Command]
name = "ai12"
command = z, c, U, F, U, D, U, c, z, z+b, F, y, z, F, x, D
time = 1
[Command]
name = "ai13"
command = z, c, U, F, c, U, F, U, F, y, z, F, x, D, z, c
time = 1
[Command]
name = "ai14"
command = c,z,c,U,F,c,U,F,D,F,x+z,c,z,
time = 1
[Command]
name = "ai15"
command = z,c,U,F,c,U,z,F,x,D,a,F,z,U,F,U,F,y,z,F,x,D,z,c,z,c,z
time = 1
[Command]
name = "ai16"
command = z,c,U,F,c,U,F,U,F,y,z,F,x,D,b,c,a,x
time = 1
[Command]
name = "ai17"
command = z,c,F,y,z,F,F,x,D,b,c,a,x,D,z,c,z,c,z
time = 1
[Command]
name = "ai18"
command = c,z,c,U,F,c,U,F,c,z
time = 1
[Command]
name = "ai19"
command = z,c,U,F,c,U,z,x,D,a,F,z,U,F,U,F,y,z,F
time = 1
[Command]
name = "ai20"
command = z,c,U,U,F,c,U,F,U,F,c,U,F,U,F,y,z,D,F,x+z
time = 1
[Command]
name = "ai21"
command = z,c,D,F,U,DF,y,z+c,F,z,c,D,F,U
time = 1
[Command]
name = "ai22"
command = F,x,D,a,F,z,U,DF,y,z+c,x,D,a,F,z,U
time = 1
[Command]
name = "ai23"
command = z,c,U,F,U,D,U,c,z,D,a,F,z,U,y,z,F,x,D,z,c
time = 1
[Command]
name = "ai24"
command = z+b,F,y,z,F,x,z,c,U,F,c,U,F,U,F,z,c,z
time = 1
[Command]
name = "ai25"
command = F,U,c,x,F,U,c,x,F,U,c,x,F,U,c,x,FU,c+x
time = 1
[Command]
name = "ai26"
command = c,z,c,U,F,c,U,F,D,F,x+z,c,z,c,U,F,U,F,y
time = 1
[Command]
name = "ai27"
command = D,a,F,z,U,F,U,F,y,z,c,U,F,c,U,z,F,x
time = 1
[Command]
name = "ai28"
command = z,c,U,F,z,F,x,D,b,c,a,x,D
time = 1
[Command]
name = "ai29"
command = z,c,F,y,z,F,F,x,z,c,z,c,z,x,D,b,c,a
time = 1
[Command]
name = "ai30"
command = c,z,c,U,F,c,U,U,F,c,U,z,F,x,z,F,F
time = 1
[Command]
name = "ai31"
command = D,a,F,z,U,F,U,F,y,x+z,c,z,c,U,F,U,F,y+z
time = 1
[Command]
name = "ai32"
command = z,c,U,F,z,F,x,D,b,c,a,x,D,D,b,c,a
time = 1
[Command]
name = "ai33"
command = z,c,F,y,z,F,F,x,z,c,F,D,F,c,z,c,z,x
time = 1
[Command]
name = "ai34"
command = z,c,D,y,z+c,F,z,c,D,F,U,F,U,DF
time = 1
[Command]
name = "ai35"
command = F,x,D,a,F,z,x,D,a,F,z,UD,a,F,z,U
time = 1
[Command]
name = "ai36"
command = z,c,U,F,U,D,U,U,DF,y,z+c,c,z,y,z,F,x,D,z,c
time = 1
[Command]
name = "ai37"
command = z+b,F,y,z,F,U,F,z,c,z,F,x,z,c,U,F,c,U
time = 1
[Command]
name = "ai38"
command = F,U,c,x,F,U,c,x,F,U,c,x,F,c,U,F,D,F
time = 1
[Command]
name = "ai39"
command = c,z,c,U,F,x+z,c,U,c,x,FU,c+z,c,U,F,U,F,y
time = 1
[Command]
name = "ai40"
command = F,z,c,z,F,x,z,c,U,F,c,U,x,FU,c+z,c,U,F,U,F,y
time = 1
[Command]
name = "ai41"
command = F,U,c,x,F,U,c,x,F,F,D,F,z+b,F,y,z,F,U
time = 1
[Command]
name = "ai42"
command = c,z,c,U,F,U,c,x,F,c,U,x+z,c,U,c,z,x,a
time = 1


;-----
;HUMAN
;-----


[Command]
name = "fatal"
command = ~D, D, x+y
time = 15

[Command]
name = "funeral"
command = ~D, D, a+b
time = 15

[Command]
name = "emma-o"
command = ~D, DF, F, x+y
time = 15

[Command]
name = "alma"
command = ~D, DF, F, a+b
time = 15

[Command]
name = "posesion"
command = x+a

[Command]
name = "posesion"
command = y+b

;-| Special Motions |------------------------------------------------------

[Command]
name = "kwaidan"
command = ~D, DF, F, a

[Command]
name = "kwaidan"
command = ~D, DF, F, b

[Command]
name = "suicidio"
command = ~D, DF, F, x

[Command]
name = "suicidio"
command = ~D, DF, F, y

[Command]
name = "okiku"
command = D, D, x

[Command]
name = "okiku"
command = D, D, y

[Command]
name = "mujer-de-nieve"
command = D, D, a

[Command]
name = "mujer-de-nieve"
command = D, D, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "fwd"
command = F
time = 1

[Command]
name = "back"
command = B
time = 1

[Command]
name = "up"
command = U
time = 1

[Command]
name = "down"
command = D
time = 1

[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================

;fatal move
[State -1, Emma-O]
type = ChangeState
value = 3500
triggerall = command = "fatal"
triggerall = power >= 3000
triggerall = life  <= 250
triggerall = var(10) = 0
triggerall = roundstate = 2
trigger1 = ctrl
trigger1 = statetype != A

;Emma-O
[State -1, Emma-O]
type = ChangeState
value = 3000
triggerall = command = "emma-o"
triggerall = power >= 1000
triggerall = var(10) = 0
triggerall = roundstate = 2
trigger1 = ctrl
trigger1 = statetype != A
trigger2 = stateno = 210
trigger2 = movecontact

;castigo del alma
[State -1, suicidio]
type = ChangeState
value = 3200
triggerall = command = "alma"
triggerall = power >= 1000
triggerall = var(10) = 0
triggerall = roundstate = 2
trigger1 = statetype != A
trigger1 = ctrl

;funeral
[State -1, suicidio]
type = ChangeState
value = 3300
triggerall = command = "funeral"
triggerall = power >= 1000
triggerall = var(10) = 0
triggerall = roundstate = 2
trigger1 = ScreenPos Y >= 70
;trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 210) || (stateno = 610)
trigger2 = movecontact

;Posesion
[State -1, Posesion]
type = ChangeState
value = 3100
triggerall = command = "posesion"
triggerall = power >= 2000
triggerall = var(10) = 0
triggerall = roundstate = 2
trigger1 = statetype != A
trigger1 = ctrl


;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
var(1) = 1

;---------------------------------------------------------------------------
; Llanto de Okiku
[State -1, Llanto de Okiku]
type = ChangeState
value = 1100
triggerall = command = "okiku"
triggerall = var(10) = 0
triggerall = statetype != A
triggerall = roundstate=2 
trigger1 = ctrl

;---------------------------------------------------------------------------
;final sangriento
[State -1, suicidio]
type = ChangeState
value = 1000
triggerall = command = "suicidio"
triggerall = var(10) = 0
triggerall = statetype != A
triggerall = roundstate=2 
trigger1 = ctrl
trigger2 = stateno = 210; || stateno = 440
trigger2 = movecontact
trigger3 = helper(1300), movecontact && stateno != 1000

;---------------------------------------------------------------------------
;mujer de nieve
[State -1, elevacion]
type = ChangeState
value = 1200
triggerall = command = "mujer-de-nieve"
triggerall = var(10) = 0
triggerall = statetype != A
triggerall = roundstate=2 
trigger1 = ctrl
trigger2 = stateno = 210 || stateno = 440
trigger2 = movecontact

;---------------------------------------------------------------------------
;mujer de nieve aerea
[State -1, elevacion aerea]
type = ChangeState
value = 1200
triggerall = command = "mujer-de-nieve"
triggerall = var(10) = 0
trigger1 = statetype != C
trigger1 = statetype != S
trigger1 = ScreenPos Y >= 70
trigger1 = ctrl
trigger2 = stateno = 610
trigger2 = movecontact
trigger3 = helper(1300), movecontact

;---------------------------------------------------------------------------
;kwaidan
[State -1, suicidio]
type = ChangeState
value = 1300
triggerall = command = "kwaidan"
triggerall = var(10) = 0
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 210
trigger2 = movecontact

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd AIR
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 101
trigger1 = command = "FF"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;throw punch
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = command = "y"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;---------------------------------------------------------------------------
;throw kick
[State -1, Kung Fu Throw]
type = ChangeState
value = 850
triggerall = command = "b"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H


;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6
trigger3 = stateno = 230
trigger3 = movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) || (stateno = 230) || (stateno = 240)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) || (stateno = 240)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Standing Strong Kick
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) || (stateno = 230)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 430)
trigger2 = movecontact
;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430) || (stateno = 440)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430) || (stateno = 410)
trigger2 = movecontact


;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 630
trigger2 = movecontact


;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 || stateno = 610
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking


;-------------------------------------------------------------------
;-------------------------------------------------------------------
;-----AI------------------------------------------------------------
;-------------------------------------------------------------------
;-------------------------------------------------------------------

[State -1]
type = VarSet
triggerall = var(24) !=1 && roundstate=2
trigger1 = command = "ai" || command = "ai2" || command = "ai3" || command = "ai4"
trigger2 = command = "ai5" || command = "ai6" || command = "ai7" || command = "ai8"
trigger3 = command = "ai9" || command = "ai10" || command = "ai11" || command = "ai12"
trigger4 = command = "ai13" || command = "ai14" || command = "ai15" || command = "ai16"
trigger5 = command = "ai17" || command = "ai18" || command = "ai19" || command = "ai20"
trigger6 = command = "ai21" || command = "ai22" || command = "ai23" || command = "ai24"
trigger7 = command = "ai25" || command = "ai26" || command = "ai27" || command = "ai28"
trigger8 = command = "ai29" || command = "ai30" || command = "ai31" || command = "ai32"
trigger9 = command = "ai33" || command = "ai34" || command = "ai35" || command = "ai36"
trigger10 = command = "ai37" || command = "ai38" || command = "ai39" || command = "ai40"
trigger11 = command = "ai41" || command = "ai42"
Trigger12  = NumHelper(10000)
Trigger12  = Helper(10000),var(59)
v = 24
value = 1

[State -1, AI_VarSet]
Type       = VarSet
TriggerAll = Var(24)    = 1
Trigger1   = RoundState = 4
Trigger2   = Win        = 1
Trigger3   = Lose       = 1
Trigger4   = DrawGame   = 1
V          = 24
Value      = -1

[State -1, AI_VarSet]
Type       = VarSet
TriggerAll = Var(24)    = -1
Trigger1   = RoundState = 2
V          = 24
Value      = 1

[State -2, DisplayToClipboard]
Type           = null;AppendToClipboard
Trigger1       = 1
Text           = "P2X:%3.0f,P2Y:%3.0f,Vx%2.2f,Vy%f2.2,Py%3.2f \n"
Params         = P2BodyDist X, P2BodyDist Y,Enemynear,Vel X,Enemynear,Vel Y,Pos Y
IgnoreHitPause = 1

[State -2, DisplayToClipboard]
Type           = AppendToClipboard
Trigger1       = 1
Text           = "AI %1d \n"
Params         = var(24)
IgnoreHitPause = 1


;Movimientos basicos
;-------------------

;run fwd
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2
triggerall = statetype != a && ctrl && stateno!=100
trigger1 = p2dist x > 60 && random < 20 && enemynear, movetype !=a
value = 100

;run fwd air
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2
triggerall = statetype = a && ctrl && stateno!=100
trigger1 = p2dist x > 60 && random < 5; && enemynear, movetype !=a
value = 101

;run back
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype != a && ctrl
trigger1 = enemynear, movetype = a && p2dist x<= 60 && random <10
;cuando esta cerca de la pared y lleva ventaja
;trigger2 = backedgedist < 4 && p2dist x >= 70 && life > 250 && random <100
trigger2 = backedgedist < 4 && random <800
Trigger2 = !((P2BodyDist X = [0,20]) && Facing = Enemynear,Facing)
;cuando esta cerca de la pared y va perdiendo
;trigger3 = backedgedist < 4 && p2dist x < 70 && life <= 250 && random <100
;trigger3 = backedgedist < 4 && random <900
value = 105

;GUARD
;-----

[State -1]
type = ChangeState
trigger1 = var(24) && roundstate=2 && ctrl
trigger1 = !(enemynear,hitdefattr=SCA,AT) && inguarddist
trigger1 = (stateno!=[120,155]); && random < 250
value = 120


;HYPERMOVES
;----------

;castigo del alma
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a && power >= 1000
trigger1 = (p2stateno!=[120,155]) && (p2statetype!=L)
trigger1 = p2dist x <= 150 && ctrl && random < -1;6 
;combo chain 1
trigger2 = ctrl
trigger2 = p2movetype = H && enemynear,stateno != [120,155]
;trigger2 = p2dist x = [40,150]
;trigger2 = P2BodyDist y + Enemynear,const(movement.yaccel) / 2 * 625 + (Enemynear,Vel y * 25) = [-80,-30]
trigger2 = p2dist x <= 150
trigger2 = Enemynear,Vel x != 7
trigger2 = p2bodydist Y + Enemynear,const(movement.yaccel) * (7 + p2bodydist X) / (7 - Enemynear,Vel x) * (7 + p2bodydist X) / (7 - Enemynear,Vel x) + Enemynear,Vel y * (7 + p2bodydist X) / (7 - Enemynear,Vel x) = [-80,-30]
trigger3 = ctrl
trigger3 = p2movetype = H && enemynear,stateno != [120,155]
trigger3 = frontedgebodydist <= 80
trigger3 = P2BodyDist y + Enemynear,const(movement.yaccel) / 2 * 64 + (Enemynear,Vel y * 8) = [-80,-30]
value = 3200

;Emma-O
[State -1, super vomitada]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a && power >= 1000
triggerall = (p2stateno!=[120,155]) && (p2statetype!=L)
trigger1 = p2dist x >= 60 && ctrl && random < 2
;combo chain 1
trigger2 = stateno = 210
trigger2 = (movecontact = [1,3]) && random < 50
;p2 salta
trigger3 = p2dist x >= 60 && ctrl && random < 5
trigger3 = enemynear, statetype = a && enemynear, vel y < 0
value = 3000

;funeral
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && power >= 1000
triggerall = (p2stateno!=[120,155]) && (p2statetype!=L)
triggerall = ScreenPos Y >= 70
triggerall = p2dist x>0
trigger1 = p2movetype != a
trigger1 = p2dist x <= 100 && ctrl && random < 6
;combo chain 1
trigger2 = stateno = 610
trigger2 = movehit = 1 && p2dist x < 30 && random < 500
trigger3 = stateno = 210
trigger3 = (movehit = [1,5]) && p2dist x < 30 && random < 50
;p2 salta
trigger4 = !(p2movetype = H && enemynear,stateno != [120,155])
trigger4 = p2dist x <= 100 && ctrl && random < 5
trigger4 = enemynear, statetype = a && enemynear, vel y < 0
value = 3300

;dark force
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a && power >= 2000
triggerall = var(10) = 0
trigger1 = ctrl && random < 4
value = 3100

;fatal move
[State -1, fatal move]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = power >= 3000 && life <= 250 && life !=0 && alive
trigger1 = p2dist x <= 120 && ctrl && random < 700 && (p2statetype!=L)
trigger1 = Enemynear,life >= 700
value = 3500


;SPECIALS
;--------

;Kwaidan
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
trigger1 = (p2stateno!=[120,155]) && (p2statetype!=L)
trigger1 = p2dist x <= 120 && ctrl && random < 5
;combo chain 1
trigger2 = stateno = 210 && moveguarded
trigger2 = backedgebodydist > 100
trigger3 = stateno = 210 && movehit && Time >= 20
value = 1300

;Mujer de nieve
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2; && statetype !=a
triggerall = (p2stateno!=[120,155]) && (p2statetype!=L) && ScreenPos Y >= 70
trigger1 = p2dist x = 190 && ctrl && random < 5
;combo chain 1
trigger2 = (stateno = 440) || (stateno = 610)
trigger2 = movecontact && random < 500
;justo despues de bloquear
trigger3 = stateno = 140 && ctrl && random < 60
trigger4 = p2dist x <= 100 && ctrl
trigger4 = Enemynear,hitdefattr = SCA, AP
trigger4 = random < 800
trigger5 = p2dist x <= 150 && ctrl
trigger5 = statetype = a && random < 800
trigger6 = stateno = 210 && moveguarded
trigger6 = backedgebodydist < 60 && random < 800
value = 1200

;final sangriento
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
trigger1 = (p2stateno!=[120,155]) && (p2statetype!=L)
trigger1 = !(p2movetype = H && enemynear,stateno != [120,155])
trigger1 = (p2dist x = [100,190]) && ctrl
trigger1 = random < (ifelse(life>250,50,20))
;combo chain 1
trigger2 = stateno = 210 && moveguarded
trigger3 = stateno = 1301 && Time >= 25
trigger3 = power < 1000 || random < 2
value = 1000

;llanto de okiku
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = !(p2movetype = H && enemynear,stateno != [120,155])
trigger1 = (p2stateno!=[120,155]) && (p2statetype!=L)
trigger1 = p2dist x <= 100 && ctrl && random < 5
;p2 ataca
trigger2 = p2dist x <= 50 && ctrl && p2statetype = a && random < 500
trigger3 = p2dist x <= 30 && ctrl && p2statetype = a && Enemynear,AnimTime < -14
trigger3 = Enemynear,hitdefattr = SCA, AA
value = 1100

;in stateno 3150
;-------------
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = stateno = 3150 && power >= 350
triggerall = random < 10
trigger1 = (p2statetype!=L)
value = ifelse(random<500, 3171, 3173)
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = stateno = 3150
triggerall = random < 950
trigger1 = (p2statetype!=L)
value = ifelse(random<500, 3170, 3172)


;ATAQUE BASICO
;-------------
;agarre
[State -1, Kung Fu Throw]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = var(10) = 0
triggerall = ctrl && (p2statetype!=L)
triggerall = stateno != 100
trigger1 = p2bodydist X < 5
trigger1 = (p2statetype = C) && (Enemynear,StateNo = [120,155])
trigger1 = p2movetype != H
value = ifelse(random<500,800,850)

;combo
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2statetype!=L)
triggerall = p2bodydist x = [0,5]
triggerall = ctrl
trigger1 = p2movetype = a && Enemynear,AnimTime < -20
trigger2 = p2movetype != a && random < 900
value = 200
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2statetype!=L)
triggerall = p2bodydist x = [0,5]
trigger1 = (stateno = 200) && movecontact
trigger2 = p2movetype != a && ctrl && random < 900
value = 230
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2statetype!=L)
triggerall = p2bodydist x = [0,15]
trigger1 = ((stateno = 230) || (stateno = 200)) && movecontact
trigger2 = p2movetype != a && ctrl && random < 300
value = 240
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2statetype!=L)
triggerall = p2bodydist x = [0,35]
trigger1 = ((stateno = [230,240]) || (stateno = 200)) && movecontact
trigger2 = p2movetype != a && ctrl && random < 300
value = 210

[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype =a
triggerall = (p2statetype!=L)
triggerall = p2bodydist x = [0,30]
triggerall = p2bodydist y = [-30,10]
triggerall = ctrl
trigger1 = p2movetype = a && Enemynear,AnimTime < -20
trigger2 = p2movetype != a && random < 900
value = ifelse(random < 500, 600, 630)
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype =a
triggerall = (p2statetype!=L)
triggerall = p2bodydist x = [0,45]
triggerall = p2bodydist y = [-30,30]
trigger1 = ((stateno = 630) || (stateno = 600)) && movecontact
trigger2 = p2movetype != a && ctrl && random < 300
trigger3 = stateno = 1350 && random < 900
value = 610
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype =a
triggerall = (p2statetype!=L)
triggerall = p2bodydist x = [0,35]
triggerall = p2bodydist y = [-30,10]
trigger1 = ((stateno = 630) || (stateno = [600,610])) && movecontact
trigger2 = p2movetype != a && ctrl && random < 300
trigger3 = stateno = 1350 && random < 900
value = 640


;primer ataque ST
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2statetype!=L)
trigger1 = (p2dist x = [0,60]) && random <70 && ctrl
;combo chain 1
;trigger2 = (stateno = 200) || (stateno = 230)
;trigger2 = movecontact
;trigger2 = (p2dist x = [0,60]) && random <300
value = ifelse(random<250 && stateno!=200,200,ifelse(random<333,210,ifelse(random<600 && stateno!=230&& stateno!=240,230,240)))

[State -1]
;combo chain para ST-HK
type = null;ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2statetype!=L)
trigger1 = stateno = 240
trigger1 = movecontact
trigger1 = (p2dist x = [0,60]) && random <200
value = ifelse(random<500,210,230)

;primer ataque CROUCH
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = (p2statetype!=L)
trigger1 = (p2dist x = [0,50]) && random <100 && ctrl
;combo chain 1
trigger2 = (stateno = 400) || (stateno = 430) || (stateno = 440)
trigger2 = movecontact
trigger2 = (p2dist x = [0,50]) && random <300
value = ifelse(random<250&&stateno!=400&&stateno!=440,400,ifelse(random<333&&stateno!=430&&stateno!=440,430,ifelse(random<500&&stateno!=440,440,410)))

;primer ataque JP
[State -1]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype = a
triggerall = (p2statetype!=L)
trigger1 = (p2dist x = [0,80]) && random <150 && ctrl
;combo chain 1
trigger2 = (p2dist x = [0,80]) && random <300
trigger2 = (stateno = 600) || (stateno = 630)
trigger2 = movecontact
value = ifelse(random<250&&stateno!=600,600,ifelse(random<333,610,ifelse(random<600&&stateno!=630,630,640)))

;agarre
[State -1, Kung Fu Throw]
type = ChangeState
triggerall = var(24)=1 && roundstate=2 && statetype !=a
triggerall = var(10) = 0
triggerall = ctrl && (p2statetype!=L)
triggerall = stateno != 100
trigger1 = p2bodydist X < 5
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger1 = enemynear, pos y > -2 && random < 250
value = ifelse(random<500,800,850)



;
;AINwp[
;
[State -3, AINpwp[]
type = helper
trigger1 = !NumHelper(10000)
;trigger1 = roundstate = 2
trigger1 = alive
trigger1 = var(24) = 0
Trigger1 = (PrevStateNo = [190,193]) || PrevStateNo = 1211 || PrevStateNo = 5900
;Trigger1 = ctrl && StateNo = 0
Trigger1 = StateNo = 0
helpertype = normal
name = "AI"
stateno = 10000
ID = 10000
pos = 9999,9999
keyctrl = 1
pausemovetime = 999999999
supermovetime = 999999999
persistent = 0

[State -3, ֌WXe[gɍsȂ悤]
type = changestate
trigger1 = ishelper(10000)
trigger1 = stateno != 10000
value = 10000

[Statedef 10000]
;anim=10000
ctrl=0

[State 10000, ԈႢŖ{̂痧ֈڍs]
type = selfstate
trigger1 = !ishelper
value = 0

[State 10000, vC[]
type = varset
trigger1 = command = "up" && root,command = "up"
trigger2 = command = "down" && root,command = "down"
trigger3 = command = "back" && root,command = "back"
trigger4 = command = "fwd" && root,command = "fwd"
trigger5 = command = "a" && root,command = "a"
trigger6 = command = "b" && root,command = "b"
trigger7 = command = "c" && root,command = "c"
trigger8 = command = "x" && root,command = "x"
trigger9 = command = "y" && root,command = "y"
trigger10 = command = "z" && root,command = "z"
trigger11 = command = "start" && root,command = "start"
var(59) = -1

[State 10000, ]
Type = DestroySelf
triggerAll = isHelper
Trigger1 = root,var(24) || var(59) = -1
trigger2 = command = "up" && root,command = "up"
trigger3 = command = "down" && root,command = "down"
trigger4 = command = "back" && root,command = "back"
trigger5 = command = "fwd" && root,command = "fwd"
trigger6 = command = "a" && root,command = "a"
trigger7 = command = "b" && root,command = "b"
trigger8 = command = "c" && root,command = "c"
trigger9 = command = "x" && root,command = "x"
trigger10 = command = "y" && root,command = "y"
trigger11 = command = "z" && root,command = "z"
trigger12 = command = "start" &&root,command ="start"

[State 10000, ׸ON]
type = varset
triggerall = var(59) != -1
TriggerAll = root,ctrl = 1
trigger1 = root,command = "up"
trigger2 = root,command = "down"
trigger3 = root,command = "back"
trigger4 = root,command = "fwd"
trigger5 = root,command = "a"
trigger6 = root,command = "b"
trigger7 = root,command = "c"
trigger8 = root,command = "x"
trigger9 = root,command = "y"
trigger10 = root,command = "z"
trigger11 = root,command = "start"
var(59) = 1
